function [D, Index] = CRAFT_AUX(x_temp, mean_global, T, t, d_num, F)

%Auxiliary function for CRAFT implementing the farthest-first heuristic (required only when lambda needs to be approximated for a specified K). 

row = size(x_temp, 1);
row_T = size(T, 1);
max_dist = 0;
max_index = 1;
sum_t = sum(t(:, :), 2);
x_num = x_temp(:, 1:d_num);
x_cat = x_temp(:, d_num+1:end);
mean_global_cat = mean_global(:, d_num+1:end);
T_num = T(:, 1:d_num);
T_cat = T(:, d_num+1:end);
t_num = t(:, 1:d_num);
t_cat = t(:, d_num+1:end);
for i=1:1:row
    global_cat = - x_cat(i, :).*log(mean_global_cat+eps) - (1-x_cat(i, :)).*log(1-mean_global_cat+eps);
    local_cat = - x_cat(i, :).*log(T_cat(1, :) + eps) - (1-x_cat(i, :)).*log(1- T_cat(1, :) +eps);
    total_num = sum(t_num(1, :).*(T_num(1, :) - x_num(i, :)) .^2 )/2;
    min_dist = sum_t(1)*F + sum(t_cat(1, :) .* local_cat) + sum((1-t_cat(1, :)).* global_cat) + total_num;
    for j=2:1:row_T
        local_cat_j = - x_cat(i, :).*log(T_cat(j, :) + eps) - (1-x_cat(i, :)).*log(1- T_cat(j, :) +eps);
        total_num_j = sum(t_num(j, :).*(T_num(j, :) - x_num(i, :)) .^2 )/2;
        dist = sum_t(j)*F + sum(t_cat(j, :) .* local_cat_j) + sum((1-t_cat(j, :)).* global_cat) + total_num_j;  %note that global_cat_j = global_cat for all j
        if dist < min_dist
           min_dist = dist;
        end
    end
    if min_dist > max_dist
       max_dist = min_dist;
       max_index = i;
    end
end
D = max_dist;
Index = max_index;
            
            