function z = nmi(x, y)  %y contains class labels
% Computes nomalized mutual information I(x,y)/sqrt(H(x)*H(y)).
% Written by Michael Chen (sth4nth@gmail.com).
    assert(numel(x) == numel(y));
    n = numel(x);
    x = reshape(x,1,n);
    y = reshape(y,1,n);
%
% Acknowledgments: Many thanks to Michael Chen, the author of this snippet.


% ------ Make cluster labels start from 1 onwards (added by Vikas Garg) -----
    if min(y)==0
       y = y + 1;
    end

   if min(x)==0
      x = x + 1;
   end
% -----------------------------------------------------------------------

    
    l = min(min(x),min(y));
    x = x-l+1;
    y = y-l+1;
    k = max(max(x),max(y));

    idx = 1:n;
    Mx = sparse(idx,x,1,n,k,n);
    My = sparse(idx,y,1,n,k,n);
    Pxy = nonzeros(Mx'*My/n); %joint distribution of x and y
    Hxy = -dot(Pxy,log2(Pxy+eps));

    Px = mean(Mx,1);
    Py = mean(My,1);

    % entropy of Py and Px
    Hx = -dot(Px,log2(Px+eps));
    Hy = -dot(Py,log2(Py+eps));

    % mutual information
    MI = Hx + Hy - Hxy;

    % normalized mutual information
    z = max(0,sqrt((MI/Hx)*(MI/Hy)));
end    